/*
 * Copyright (C) 2015 Jasper van Riet
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.jaspervanriet.huntingthatproduct.Utils;

import android.graphics.Bitmap;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Paint;

import com.squareup.picasso.Transformation;

public class CircleTransform implements Transformation {
	@Override
	public Bitmap transform (Bitmap source) {
		int size = Math.min (source.getWidth (), source.getHeight ());

		int x = (source.getWidth () - size) / 2;
		int y = (source.getHeight () - size) / 2;

		Bitmap squaredBitmap = Bitmap.createBitmap (source, x, y, size, size);
		if (squaredBitmap != source) {
			source.recycle ();
		}

		Bitmap bitmap = Bitmap.createBitmap (size, size, source.getConfig ());

		Canvas canvas = new Canvas (bitmap);
		Paint paint = new Paint ();
		BitmapShader shader = new BitmapShader (squaredBitmap, BitmapShader.TileMode.CLAMP, BitmapShader.TileMode.CLAMP);
		paint.setShader (shader);
		paint.setAntiAlias (true);

		float r = size / 2f;
		canvas.drawCircle (r, r, r, paint);

		squaredBitmap.recycle ();
		return bitmap;
	}

	@Override
	public String key () {
		return "circle";
	}
}